@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 #ifndef __DEFS_H__
@@ -64,6 +64,7 @@
 #define MATCHER_RC		"matcherrc"
 #define MENU_RC			"menurc"
 #define RENDERER_RC		"rendererrc"
+#define TAGS_RC			"tagsrc"
 #define QUICKSEARCH_HISTORY	"quicksearch_history"
 #define SUMMARY_SEARCH_FROM_HISTORY	"summarysearch_from_history"
 #define SUMMARY_SEARCH_TO_HISTORY	"summarysearch_to_history"
@@ -71,11 +72,13 @@
 #define SUMMARY_SEARCH_BODY_HISTORY	"summary_searchbody_history"
 #define SUMMARY_SEARCH_ADV_CONDITION_HISTORY	"summarysearch_adv_history"
 #define MESSAGE_SEARCH_HISTORY	"messagesearch_history"
+#define ADDRESSBOOK_CUSTOM_ATTRIBUTES "attributesrc"
 #define TEMPLATE_DIR		"templates"
 #define TMP_DIR			"tmp"
 #define UIDL_DIR		"uidl"
 #define NEWSGROUP_LIST		".newsgroup_list"
 #define ADDRESS_BOOK		"addressbook.xml"
+#define ADDRBOOK_DIR		"addrbook"
 #define MANUAL_HTML_INDEX	"claws-mail-manual.html"
 #define HOMEPAGE_URI		"http://www.claws-mail.org/"
 #define MANUAL_URI		"http://www.claws-mail.org/documentation.php"
@@ -96,8 +99,15 @@
 #define CACHE_FILE		".claws_cache"
 #define OLD_MARK_FILE		".sylpheed_mark"
 #define MARK_FILE		".claws_mark"
+#define TAGS_FILE		".claws_tags"
 #define CACHE_VERSION		24
 #define MARK_VERSION		2
+#define TAGS_VERSION		1
+
+#ifdef MAEMO
+#define MMC1_PATH "/media/mmc1"
+#define MMC2_PATH "/media/mmc2"
+#endif
 
 #ifdef G_OS_WIN32
 #  define ACTIONS_RC		"actionswinrc"
@@ -155,8 +165,9 @@
 #define FOLDER_UPDATE_INTERVAL		1500	/* msec */
 #define PROGRESS_UPDATE_INTERVAL	200	/* msec */
 #define SESSION_TIMEOUT_INTERVAL	60	/* sec */
-#define MAX_HISTORY_SIZE		16
+#define MAX_HISTORY_SIZE		32
 
+#define BOLD_FONT prefs_common.boldfont
 #define NORMAL_FONT prefs_common.normalfont
 #define SMALL_FONT	prefs_common.smallfont
 
