@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 #ifndef __MAIN_H__
@@ -22,10 +22,22 @@
 
 #include <glib.h>
 #include <gtk/gtkwidget.h>
+#ifdef MAEMO
+#ifdef CHINOOK
+#include <hildon/hildon-program.h>
+#else
+#include <hildon-widgets/hildon-program.h>
+#include <hildon-widgets/hildon-window.h>
+#endif
+#endif
 
 extern gchar *prog_version;
 extern gboolean debug_mode;
 
+#ifdef MAEMO
+extern HildonProgram *hildon_program;
+#endif
+
 void app_will_exit	(GtkWidget *widget, gpointer data);
 gboolean clean_quit	(gpointer data);
 gboolean claws_is_exiting(void);
@@ -34,4 +46,8 @@ gchar *claws_get_socket_name(void);
 void main_set_show_at_startup(gboolean show);
 gboolean claws_crashed(void);
 
+#ifdef HAVE_NETWORKMANAGER_SUPPORT
+gboolean networkmanager_is_online(GError **error);
+#endif
+
 #endif /* __MAIN_H__ */
