@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 #ifndef PREFS_FOLDER_ITEM_H
@@ -31,7 +31,5 @@
 void prefs_folder_item_create(FolderView *folderview, FolderItem *item); 
 
 void prefs_folder_item_open		(FolderItem 	*item);
-void prefs_folder_item_register_page	(PrefsPage 	*page);
-void prefs_folder_item_unregister_page	(PrefsPage 	*page);
 
 #endif /* PREFS_FOLDER_ITEM_H */
