@@ -33,30 +33,42 @@ gint quote_fmt_get_cursor_pos(void);
 void quotefmt_create_new_msg_fmt_widgets(GtkWindow *parent_window,
 						GtkWidget *parent_box,
 						GtkWidget **checkbtn_compose_with_format,
+						GtkWidget **override_from_format,
 						GtkWidget **edit_subject_format,
 						GtkWidget **edit_body_format,
-						gboolean add_info_button);
+						gboolean add_info_button,
+						void(*set_defaults_func)(void));
 void quotefmt_create_reply_fmt_widgets(GtkWindow *parent_window,
 						GtkWidget *parent_box,
 						GtkWidget **checkbtn_reply_with_format,
+						GtkWidget **override_from_format,
 						GtkWidget **edit_reply_quotemark,
 						GtkWidget **edit_reply_format,
-						gboolean add_info_button);
+						gboolean add_info_button,
+						void(*set_defaults_func)(void));
 void quotefmt_create_forward_fmt_widgets(GtkWindow *parent_window,
 						GtkWidget *parent_box,
 						GtkWidget **checkbtn_forward_with_format,
+						GtkWidget **override_from_format,
 						GtkWidget **edit_fw_quotemark,
 						GtkWidget **edit_fw_format,
-						gboolean add_info_button);
+						gboolean add_info_button,
+						void(*set_defaults_func)(void));
 void quotefmt_add_info_button(GtkWindow *parent_window, GtkWidget *parent_box);
+void quotefmt_add_defaults_button(GtkWindow *parent_window,
+								  GtkWidget *parent_box,
+								  void(*set_defaults_func)(void));
 
 void quotefmt_check_new_msg_formats(gboolean use_format,
+									gchar *override_from_fmt,
 									gchar *subject_fmt,
 									gchar *body_fmt);
 void quotefmt_check_reply_formats(gboolean use_format,
+									gchar *override_from_fmt,
 									gchar *quotation_mark,
 									gchar *body_fmt);
 void quotefmt_check_forward_formats(gboolean use_format,
+									gchar *override_from_fmt,
 									gchar *quotation_mark,
 									gchar *body_fmt);
 
