@@ -88,6 +88,7 @@ struct _SummaryColumnState
 struct _SummaryView
 {
 	GtkWidget *vbox;
+	GtkWidget *mainwidget_book;
 	GtkWidget *scrolledwin;
 	GtkWidget *ctree;
 	GtkWidget *hbox;
@@ -102,7 +103,7 @@ struct _SummaryView
 	GtkWidget *statlabel_msgs;
 	GtkWidget *toggle_eventbox;
 	GtkWidget *toggle_arrow;
-#ifdef MAEMO
+#ifdef GENERIC_UMPC
 	GtkWidget *multiple_sel_togbtn;
 	GtkWidget *multiple_sel_image;
 #endif
@@ -152,7 +153,7 @@ struct _SummaryView
 
 	/* current message status */
 	gint   unreadmarked;
-	off_t  total_size;
+	goffset total_size;
 	gint   deleted;
 	gint   moved;
 	gint   copied;
@@ -321,4 +322,5 @@ void summaryview_activate_quicksearch(SummaryView *summaryview, gboolean show);
 void summary_set_menu_sensitive	(SummaryView		*summaryview);
 void summary_relayout(SummaryView *summaryview);
 void summary_update_unread(SummaryView *summaryview, FolderItem *removed_item);
+gboolean summary_is_list(SummaryView *summaryview);
 #endif /* __SUMMARY_H__ */
